Crate codex_file_system

Crate codex_file_system 

Structs

CopyOptions
CreateDirectoryOptions
ExecFileSystemSandboxEntry
FileMetadata
FileSystemReadStream
Stream of immutable chunks read from an ExecutorFileSystem.
FileSystemSandboxContext
ReadDirectoryEntry
RemoveOptions
WalkEntry
One entry returned by a walk.
WalkError
A descendant that could not be inspected during a walk.
WalkOptions
Bounds for a recursive filesystem walk.
WalkOutcome
Entries and recoverable errors collected by a bounded walk.

Enums

ExecFileSystemPath
ExecManagedFileSystemPermissions
ExecPermissionProfile
FindUpErrorPolicy
Controls how an upward marker search handles metadata errors other than NotFound.
WalkEntryKind
Type of a filesystem entry returned by a walk.

Constants

FILE_READ_CHUNK_SIZE
Maximum chunk size returned by ExecutorFileSystem::read_file_stream.

Traits

ExecutorFileSystem
Abstract filesystem access used by components that may operate locally or via a remote environment.

Functions

find_nearest_ancestor_with_markers
Finds the nearest ancestor containing one of the provided marker names.
find_nearest_native_ancestor_with_markers
Finds the nearest native ancestor containing one of the provided marker names.

Type Aliases

ExecutorFileSystemFuture
Future returned by ExecutorFileSystem operations.
FileSystemResult