pub struct WalkOptions {
pub max_depth: usize,
pub max_directories: usize,
pub max_entries: usize,
pub follow_directory_symlinks: bool,
pub prune_hidden_directories: bool,
}Expand description
Bounds for a recursive filesystem walk.
Fields
max_depth: usizeMaximum directory depth below the root that may be traversed.
max_directories: usizeMaximum number of directories that may be traversed, including the root.
max_entries: usizeMaximum number of directory entries that may be examined.
follow_directory_symlinks: boolWhether directory symlinks should be followed.
Whether directories whose names start with . should be returned but not traversed.