Structs
- Copy
Options - Create
Directory Options - Exec
File System Sandbox Entry - File
Metadata - File
System Read Stream - Stream of immutable chunks read from an
ExecutorFileSystem. - File
System Sandbox Context - Read
Directory Entry - Remove
Options - Walk
Entry - One entry returned by a walk.
- Walk
Error - A descendant that could not be inspected during a walk.
- Walk
Options - Bounds for a recursive filesystem walk.
- Walk
Outcome - Entries and recoverable errors collected by a bounded walk.
Enums
- Exec
File System Path - Exec
Managed File System Permissions - Exec
Permission Profile - Find
UpError Policy - Controls how an upward marker search handles metadata errors other than
NotFound. - Walk
Entry Kind - Type of a filesystem entry returned by a walk.
Constants
- FILE_
READ_ CHUNK_ SIZE - Maximum chunk size returned by
ExecutorFileSystem::read_file_stream.
Traits
- Executor
File System - Abstract filesystem access used by components that may operate locally or via a remote environment.
Functions
- find_
nearest_ ancestor_ with_ markers - Finds the nearest ancestor containing one of the provided marker names.
- find_
nearest_ native_ ancestor_ with_ markers - Finds the nearest native ancestor containing one of the provided marker names.
Type Aliases
- Executor
File System Future - Future returned by
ExecutorFileSystemoperations. - File
System Result